import { useObservableResource } from "@reactive-js/react";
import { map, pipe, scan } from "@reactive-js/observable-resource";
import { createElement } from "react";
const empty = {
    path: "",
    query: "",
    fragment: "",
};
export const Router = function Router(props) {
    const { locationStoreFactory, notFound, routes, scheduler } = props;
    const element = useObservableResource(() => {
        const routeMap = {};
        for (const [path, component] of routes) {
            routeMap[path] = component;
        }
        const locationResource = locationStoreFactory();
        const uriUpdater = (updater) => {
            locationResource.dispatch(updater);
        };
        const pairify = ([_, oldState], next) => oldState === empty ? [undefined, next] : [oldState, next];
        return pipe(locationResource, scan(pairify, [undefined, empty]), map(([referer, uri]) => createElement(routeMap[uri.path] || notFound, {
            referer,
            uri,
            uriUpdater,
        })));
    }, [locationStoreFactory, notFound, routes], scheduler);
    return (element !== null && element !== void 0 ? element : null);
};
//# sourceMappingURL=router.js.map